@@ -5,7 +5,7 @@
 # This file is part of the R package RPACT - R Package for Adaptive Clinical Trials. #
 #                                                                                    #
 # File version: 1.0.0                                                                #
-# Date: 23 July 2019, 11:47:00                                                       #
+# Date: 11 September 2019, 13:42:27                                                  #
 # Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD                             #
 # Licensed under "GNU Lesser General Public License" version 3                       #
 # License text can be found here: https://www.r-project.org/Licenses/LGPL-3          #
@@ -23,6 +23,7 @@ context("Testing simulation survival function")
 test_that("'getSimulationSurvival': configuration 1", {
 	.skipTestifDisabled()
 
+	# @refFS[Sec.]{fs:subsec:seed}
 	simulationResults <- getSimulationSurvival(maxNumberOfSubjects = 200, plannedEvents = 50, 
 		accrualTime = c(0, 3, 6, 12), accrualIntensity = c(0.1, 0.2, 0.2) , 
 		maxNumberOfIterations = 100, seed = 1234567890)
@@ -79,7 +80,7 @@ test_that("'getSimulationSurvival': configuration 2", {
 	expect_equal(simulationResults$analysisTime[2, ], c(10.130549, 10.39649, 10.458778, 9.7641943), tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], c(13.506679, 14.455396, 18.382917, 18.866629), tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, c(8.500396, 9.4448778, 11.628285, 12.227203), tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20), tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20))
 	expect_equal(simulationResults$eventsPerStage[2, ], c(84.483333, 93.054795, 98.884615, 92.015385), tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], c(125.8, 159.44444, 229.53571, 250.93478), tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, c(60.755833, 79.305068, 118.11231, 139.91292), tolerance = 1e-07)
@@ -98,7 +99,7 @@ test_that("'getSimulationSurvival': configuration 2", {
 	expect_equal(simulationResults$futilityPerStage[2, ], c(0, 0.01, 0, 0.04), tolerance = 1e-07)
 	expect_equal(simulationResults$futilityStop, c(0, 0.07, 0.02, 0.26), tolerance = 1e-07)
 	expect_equal(simulationResults$earlyStop, c(0.95, 0.91, 0.72, 0.54), tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], c(0.61612368, 0.57564124, 0.49458667, 0.52832804), tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], c(0.78816558, 0.77803263, 0.64572713, 0.66129837), tolerance = 1e-07)
 })
@@ -133,7 +134,7 @@ test_that("'getSimulationSurvival': configuration 3", {
 	expect_equal(simulationResults$analysisTime[2, ], c(16.764021, 14.756285, 13.821816, 12.988284), tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], c(38.977945, 24.200748, 26.934721, 11.875967), tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, c(22.098154, 13.978342, 11.899449, 9.7796143), tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20), tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20))
 	expect_equal(simulationResults$eventsPerStage[2, ], c(106.50725, 94.541667, 94.677966, 94.48), tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], c(259.13514, 175, 204, 84.5), tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, c(136.16232, 83.325, 71.712542, 57.0404), tolerance = 1e-07)
@@ -142,7 +143,7 @@ test_that("'getSimulationSurvival': configuration 3", {
 	expect_equal(simulationResults$eventsNotAchieved[3, ], c(0, 0, 0, 0))
 	expect_equal(simulationResults$numberOfSubjects[1, ], c(275.04, 265.86, 248.46, 231.45), tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[2, ], c(496.07246, 481.84722, 476, 463.84), tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], c(500, 500, 500, 494), tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[3, ], c(500, 500, 500, 494))
 	expect_equal(simulationResults$expectedNumberOfSubjects, c(429.00559, 423.54913, 384.3886, 348.2482), tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[1, ], c(0.18, 0.22, 0.39, 0.49), tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[2, ], c(0.31, 0.59, 0.52, 0.48), tolerance = 1e-07)
@@ -152,7 +153,7 @@ test_that("'getSimulationSurvival': configuration 3", {
 	expect_equal(simulationResults$futilityPerStage[2, ], c(0.01, 0.01, 0, 0), tolerance = 1e-07)
 	expect_equal(simulationResults$futilityStop, c(0.14, 0.07, 0.02, 0.01), tolerance = 1e-07)
 	expect_equal(simulationResults$earlyStop, c(0.63, 0.88, 0.93, 0.98), tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], c(0.46273079, 0.58305775, 0.61313502, 0.59484117), tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], c(0.66165116, 0.75066235, 0.71981679, 0.8), tolerance = 1e-07)
 
@@ -192,7 +193,7 @@ test_that("'getSimulationSurvival': configuration 4", {
 	expect_equal(simulationResults$analysisTime[2, ], 12.345684, tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], 36.687962, tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, 19.26207, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], 20, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], 20)
 	expect_equal(simulationResults$eventsPerStage[2, ], 91.694737, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], 207.83333, tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, 122.95158, tolerance = 1e-07)
@@ -211,7 +212,7 @@ test_that("'getSimulationSurvival': configuration 4", {
 	expect_equal(simulationResults$futilityPerStage[2, ], 0)
 	expect_equal(simulationResults$futilityStop, 0)
 	expect_equal(simulationResults$earlyStop, 0.7, tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], 0.49425129, tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], 0.73157546, tolerance = 1e-07)
 
@@ -247,7 +248,7 @@ test_that("'getSimulationSurvival': configuration 5", {
 	expect_equal(simulationResults$analysisTime[2, ], c(12.354338, 12.56529, 12.380125, 12.254955), tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], c(16.473595, 17.9949, 17.847597, 17.390492), tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, c(12.562909, 13.818364, 15.044701, 16.144285), tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20), tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20, 20))
 	expect_equal(simulationResults$eventsPerStage[2, ], c(48.54023, 51.561798, 55.130435, 55.79), tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], c(75.277778, 87.176471, 94.103448, 94.545455), tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, c(49.642759, 60.198989, 74.924348, 85.6317), tolerance = 1e-07)
@@ -266,7 +267,7 @@ test_that("'getSimulationSurvival': configuration 5", {
 	expect_equal(simulationResults$futilityPerStage[2, ], c(0, 0, 0, 0))
 	expect_equal(simulationResults$futilityStop, c(0, 0, 0, 0))
 	expect_equal(simulationResults$earlyStop, c(0.82, 0.66, 0.42, 0.23), tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], c(0.56161185, 0.47418383, 0.31608317, 0.29578133), tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], c(0.71394365, 0.57778506, 0.37448609, 0.32265113), tolerance = 1e-07)
 
@@ -306,18 +307,18 @@ test_that("'getSimulationSurvival': configuration 6", {
 	expect_equal(simulationResults$analysisTime[2, ], 137.1048, tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], 83.267347, tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, 10.437225, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], 20, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], 20)
 	expect_equal(simulationResults$eventsPerStage[2, ], 102.10345, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], 96.375, tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, 96.661422, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsNotAchieved[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResults$eventsNotAchieved[2, ], 0.71, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsNotAchieved[3, ], 0.16, tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[1, ], 179.93, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[2, ], 200, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[2, ], 200)
+	expect_equal(simulationResults$numberOfSubjects[3, ], 200)
 	expect_equal(simulationResults$expectedNumberOfSubjects, 200)
-	expect_equal(simulationResults$rejectPerStage[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResults$rejectPerStage[1, ], 0)
 	expect_equal(simulationResults$rejectPerStage[2, ], 0.05, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[3, ], 0.03, tolerance = 1e-07)
 	expect_equal(simulationResults$overallReject, 0.08, tolerance = 1e-07)
@@ -325,7 +326,7 @@ test_that("'getSimulationSurvival': configuration 6", {
 	expect_equal(simulationResults$futilityPerStage[2, ], 0)
 	expect_equal(simulationResults$futilityStop, 0)
 	expect_equal(simulationResults$earlyStop, 0.05, tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], 0.80243482, tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], 0.8, tolerance = 1e-07)
 
@@ -364,18 +365,18 @@ test_that("'getSimulationSurvival': configuration 7", {
 	expect_equal(simulationResults$analysisTime[2, ], 43.00709, tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], 62.010907, tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, 8.0301114, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], 20, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], 20)
 	expect_equal(simulationResults$eventsPerStage[2, ], 87.076923, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], 122.5, tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, 121.79154, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsNotAchieved[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResults$eventsNotAchieved[2, ], 0.74, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsNotAchieved[3, ], 0.12, tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[1, ], 183.49, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[2, ], 200, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[2, ], 200)
+	expect_equal(simulationResults$numberOfSubjects[3, ], 200)
 	expect_equal(simulationResults$expectedNumberOfSubjects, 200)
-	expect_equal(simulationResults$rejectPerStage[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResults$rejectPerStage[1, ], 0)
 	expect_equal(simulationResults$rejectPerStage[2, ], 0.02, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[3, ], 0.04, tolerance = 1e-07)
 	expect_equal(simulationResults$overallReject, 0.06, tolerance = 1e-07)
@@ -383,7 +384,7 @@ test_that("'getSimulationSurvival': configuration 7", {
 	expect_equal(simulationResults$futilityPerStage[2, ], 0)
 	expect_equal(simulationResults$futilityStop, 0)
 	expect_equal(simulationResults$earlyStop, 0.02, tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], 0.80311744, tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], 0.8, tolerance = 1e-07)
 
@@ -409,8 +410,6 @@ test_that("'getSimulationSurvival': configuration 8", {
 	## Comparison of the results of SimulationResultsSurvival object 'simulationResults' with expected results
 	##
 	expect_equal(simulationResults$accrualIntensity, c(9.5238095, 19.047619, 19.047619), tolerance = 1e-07)
-	expect_equal(simulationResults$pi1, c(0.091535984, 0.25023841), tolerance = 1e-07)
-	expect_equal(simulationResults$pi2, c(0.11307956, 0.30232367), tolerance = 1e-07)
 	expect_equal(simulationResults$lambda1, c(0.008, 0.024), tolerance = 1e-07)
 	expect_equal(simulationResults$iterations[1, ], 100)
 	expect_equal(simulationResults$iterations[2, ], 99)
@@ -427,8 +426,8 @@ test_that("'getSimulationSurvival': configuration 8", {
 	expect_equal(simulationResults$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResults$eventsNotAchieved[3, ], 0)
 	expect_equal(simulationResults$numberOfSubjects[1, ], 199.73, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[2, ], 200, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[2, ], 200)
+	expect_equal(simulationResults$numberOfSubjects[3, ], 200)
 	expect_equal(simulationResults$expectedNumberOfSubjects, 199.9973, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[1, ], 0.01, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[2, ], 0.04, tolerance = 1e-07)
@@ -438,7 +437,7 @@ test_that("'getSimulationSurvival': configuration 8", {
 	expect_equal(simulationResults$futilityPerStage[2, ], 0)
 	expect_equal(simulationResults$futilityStop, 0)
 	expect_equal(simulationResults$earlyStop, 0.05, tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], 0.13387917, tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], 0.12806393, tolerance = 1e-07)
 
@@ -465,8 +464,6 @@ test_that("'getSimulationSurvival': configuration 9; ", {
 	## Comparison of the results of SimulationResultsSurvival object 'simulationResults' with expected results
 	##
 	expect_equal(simulationResults$accrualIntensity, c(9.5238095, 19.047619, 19.047619), tolerance = 1e-07)
-	expect_equal(simulationResults$pi1, c(0.086068815, 0.23662051), tolerance = 1e-07)
-	expect_equal(simulationResults$pi2, c(0.11307956, 0.30232367), tolerance = 1e-07)
 	expect_equal(simulationResults$lambda1, c(0.0075, 0.0225), tolerance = 1e-07)
 	expect_equal(simulationResults$iterations[1, ], 100)
 	expect_equal(simulationResults$iterations[2, ], 27)
@@ -475,16 +472,16 @@ test_that("'getSimulationSurvival': configuration 9; ", {
 	expect_equal(simulationResults$analysisTime[2, ], 43.719076, tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], 38.174522, tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, 6.7834542, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], 20, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], 20)
 	expect_equal(simulationResults$eventsPerStage[2, ], 90.037037, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], 84.5, tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, 84.519444, tolerance = 1e-07)
-	expect_equal(simulationResults$eventsNotAchieved[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResults$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResults$eventsNotAchieved[2, ], 0.72, tolerance = 1e-07)
 	expect_equal(simulationResults$eventsNotAchieved[3, ], 0.13, tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[1, ], 199.79, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[2, ], 200, tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[2, ], 200)
+	expect_equal(simulationResults$numberOfSubjects[3, ], 200)
 	expect_equal(simulationResults$expectedNumberOfSubjects, 199.9979, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[1, ], 0.01, tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[2, ], 0.12, tolerance = 1e-07)
@@ -494,7 +491,7 @@ test_that("'getSimulationSurvival': configuration 9; ", {
 	expect_equal(simulationResults$futilityPerStage[2, ], 0)
 	expect_equal(simulationResults$futilityStop, 0)
 	expect_equal(simulationResults$earlyStop, 0.13, tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], 0.80261071, tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], 0.8, tolerance = 1e-07)
 
@@ -533,16 +530,16 @@ test_that("'getSimulationSurvival': configuration 10; ", {
 	expect_equal(simulationResults$analysisTime[2, ], c(41.567704, 37.665074, 37.552932), tolerance = 1e-07)
 	expect_equal(simulationResults$analysisTime[3, ], c(33.732435, 53.513221, 36.546609), tolerance = 1e-07)
 	expect_equal(simulationResults$studyDuration, c(6.1071436, 6.3055402, 2.5582627), tolerance = 1e-07)
-	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20), tolerance = 1e-07)
+	expect_equal(simulationResults$eventsPerStage[1, ], c(20, 20, 20))
 	expect_equal(simulationResults$eventsPerStage[2, ], c(95.290323, 89.541667, 93.9375), tolerance = 1e-07)
 	expect_equal(simulationResults$eventsPerStage[3, ], c(93.8, 124, 109.71429), tolerance = 1e-07)
 	expect_equal(simulationResults$expectedNumberOfEvents, c(93.949032, 120.19708, 109.71429), tolerance = 1e-07)
-	expect_equal(simulationResults$eventsNotAchieved[1, ], c(0, 0, 0), tolerance = 1e-07)
+	expect_equal(simulationResults$eventsNotAchieved[1, ], c(0, 0, 0))
 	expect_equal(simulationResults$eventsNotAchieved[2, ], c(0.69, 0.74, 0.84), tolerance = 1e-07)
 	expect_equal(simulationResults$eventsNotAchieved[3, ], c(0.16, 0.14, 0.09), tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[1, ], c(173.61, 170.39, 165.9), tolerance = 1e-07)
 	expect_equal(simulationResults$numberOfSubjects[2, ], c(199.6129, 200, 200), tolerance = 1e-07)
-	expect_equal(simulationResults$numberOfSubjects[3, ], c(200, 200, 200), tolerance = 1e-07)
+	expect_equal(simulationResults$numberOfSubjects[3, ], c(200, 200, 200))
 	expect_equal(simulationResults$expectedNumberOfSubjects, c(199.96129, 199.4078, 200), tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[1, ], c(0, 0.02, 0), tolerance = 1e-07)
 	expect_equal(simulationResults$rejectPerStage[2, ], c(0.1, 0.05, 0), tolerance = 1e-07)
@@ -552,7 +549,7 @@ test_that("'getSimulationSurvival': configuration 10; ", {
 	expect_equal(simulationResults$futilityPerStage[2, ], c(0, 0, 0))
 	expect_equal(simulationResults$futilityStop, c(0, 0, 0))
 	expect_equal(simulationResults$earlyStop, c(0.1, 0.07, 0), tolerance = 1e-07)
-	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(simulationResults$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_))
 	expect_equal(simulationResults$conditionalPowerAchieved[2, ], c(0.80326129, 0.80161244, 0.8), tolerance = 1e-07)
 	expect_equal(simulationResults$conditionalPowerAchieved[3, ], c(0.8, 0.8, 0.8), tolerance = 1e-07)
 
@@ -930,7 +927,7 @@ test_that("'getSimulationSurvival': Specify effect size for a two-stage group de
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 199.47, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.9841, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.03, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.24, tolerance = 1e-07)
@@ -938,7 +935,7 @@ test_that("'getSimulationSurvival': Specify effect size for a two-stage group de
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.03, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.29516222, tolerance = 1e-07)
 
 })
@@ -976,8 +973,8 @@ test_that("'getSimulationSurvival': As above, but with a three-stage O'Brien and
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[3, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 195.313, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[3, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
+	expect_equal(simulationResult$numberOfSubjects[3, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.92969, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.015, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.124, tolerance = 1e-07)
@@ -987,7 +984,7 @@ test_that("'getSimulationSurvival': As above, but with a three-stage O'Brien and
 	expect_equal(simulationResult$futilityPerStage[2, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.139, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.19637573, tolerance = 1e-07)
 	expect_equal(simulationResult$conditionalPowerAchieved[3, ], 0.23542216, tolerance = 1e-07)
 
@@ -1021,7 +1018,7 @@ test_that("'getSimulationSurvival': Effect size is based on event rate at specif
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 199.69, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.9752, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.08, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.44, tolerance = 1e-07)
@@ -1029,7 +1026,7 @@ test_that("'getSimulationSurvival': Effect size is based on event rate at specif
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.08, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.43087375, tolerance = 1e-07)
 
 })
@@ -1062,7 +1059,7 @@ test_that("'getSimulationSurvival': Effect size is based on hazard rate for the
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 195.5, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.73, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.06, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.43, tolerance = 1e-07)
@@ -1070,7 +1067,7 @@ test_that("'getSimulationSurvival': Effect size is based on hazard rate for the
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.06, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.48014443, tolerance = 1e-07)
 
 })
@@ -1088,8 +1085,6 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	## Comparison of the results of SimulationResultsSurvival object 'simulationResult' with expected results
 	##
 	expect_equal(simulationResult$accrualIntensity, 16.666667, tolerance = 1e-07)
-	expect_equal(simulationResult$pi1, c(0.16472979, 0.30232367, 0.51324774), tolerance = 1e-07)
-	expect_equal(simulationResult$pi2, c(0.11307956, 0.21337214, 0.38121661), tolerance = 1e-07)
 	expect_equal(simulationResult$lambda1, c(0.015, 0.03, 0.06), tolerance = 1e-07)
 	expect_equal(simulationResult$iterations[1, ], 100)
 	expect_equal(simulationResult$iterations[2, ], 96)
@@ -1102,7 +1097,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 193.51, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.7404, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.04, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.28, tolerance = 1e-07)
@@ -1110,7 +1105,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.04, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.33404702, tolerance = 1e-07)
 
 	pws <- list("0 - <5" = 0.01, "5 - <10" = 0.02, ">=10"    = 0.04)
@@ -1135,7 +1130,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 193.51, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.7404, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.04, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.28, tolerance = 1e-07)
@@ -1143,7 +1138,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.04, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.33404702, tolerance = 1e-07)
 
 })
@@ -1161,8 +1156,6 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	## Comparison of the results of SimulationResultsSurvival object 'simulationResult' with expected results
 	##
 	expect_equal(simulationResult$accrualIntensity, 16.666667, tolerance = 1e-07)
-	expect_equal(simulationResult$pi1, c(0.16472979, 0.30232367, 0.51324774), tolerance = 1e-07)
-	expect_equal(simulationResult$pi2, c(0.11307956, 0.21337214, 0.38121661), tolerance = 1e-07)
 	expect_equal(simulationResult$lambda1, c(0.015, 0.03, 0.06), tolerance = 1e-07)
 	expect_equal(simulationResult$iterations[1, ], 100)
 	expect_equal(simulationResult$iterations[2, ], 96)
@@ -1175,7 +1168,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 193.51, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.7404, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.04, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.28, tolerance = 1e-07)
@@ -1183,7 +1176,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.04, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.33404702, tolerance = 1e-07)
 
 })
@@ -1214,7 +1207,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 193.51, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 199.7404, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[1, ], 0.04, tolerance = 1e-07)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.28, tolerance = 1e-07)
@@ -1222,7 +1215,7 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0.04, tolerance = 1e-07)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.33404702, tolerance = 1e-07)
 
 })
@@ -1251,15 +1244,15 @@ test_that("'getSimulationSurvival': Specification of piecewise exponential survi
 	expect_equal(simulationResult$eventsNotAchieved[1, ], 0)
 	expect_equal(simulationResult$eventsNotAchieved[2, ], 0)
 	expect_equal(simulationResult$numberOfSubjects[1, ], 197.81, tolerance = 1e-07)
-	expect_equal(simulationResult$numberOfSubjects[2, ], 200, tolerance = 1e-07)
+	expect_equal(simulationResult$numberOfSubjects[2, ], 200)
 	expect_equal(simulationResult$expectedNumberOfSubjects, 200)
-	expect_equal(simulationResult$rejectPerStage[1, ], 0, tolerance = 1e-07)
+	expect_equal(simulationResult$rejectPerStage[1, ], 0)
 	expect_equal(simulationResult$rejectPerStage[2, ], 0.06, tolerance = 1e-07)
 	expect_equal(simulationResult$overallReject, 0.06, tolerance = 1e-07)
 	expect_equal(simulationResult$futilityPerStage[1, ], 0)
 	expect_equal(simulationResult$futilityStop, 0)
 	expect_equal(simulationResult$earlyStop, 0)
-	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_, tolerance = 1e-07)
+	expect_equal(simulationResult$conditionalPowerAchieved[1, ], NA_real_)
 	expect_equal(simulationResult$conditionalPowerAchieved[2, ], 0.1789388, tolerance = 1e-07)
 
 })
@@ -1359,7 +1352,7 @@ test_that("'getSimulationSurvival': Perform recalculation of number of events ba
 	expect_equal(resultsWithSSR1$analysisTime[2, ], c(17.76189, 17.229038, 16.567328, 16.175906, 15.668575, 15.328143, 14.604753), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$analysisTime[3, ], c(30.192276, 28.615009, 26.463502, 25.657109, 23.821118, 23.34898, 22.534023), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$studyDuration, c(29.683899, 28.160756, 25.20615, 22.190278, 19.319577, 18.030286, 14.789904), tolerance = 1e-07)
-	expect_equal(resultsWithSSR1$eventsPerStage[1, ], c(58, 58, 58, 58, 58, 58, 58), tolerance = 1e-07)
+	expect_equal(resultsWithSSR1$eventsPerStage[1, ], c(58, 58, 58, 58, 58, 58, 58))
 	expect_equal(resultsWithSSR1$eventsPerStage[2, ], c(233.65, 231.27, 229.84, 229.43878, 228.57292, 227.67677, 219.44565), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$eventsPerStage[3, ], c(409.28125, 401.01042, 385.875, 382.38806, 371.3, 374.14286, 367.72727), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$expectedNumberOfEvents, c(402.256, 394.2208, 367.1508, 328.48602, 293.11354, 277.24313, 222.84098), tolerance = 1e-07)
@@ -1368,7 +1361,7 @@ test_that("'getSimulationSurvival': Perform recalculation of number of events ba
 	expect_equal(resultsWithSSR1$eventsNotAchieved[3, ], c(0, 0, 0, 0, 0, 0, 0))
 	expect_equal(resultsWithSSR1$numberOfSubjects[1, ], c(531.25, 521.07, 500.8, 498.42, 488.13, 473.47, 464.37), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$numberOfSubjects[2, ], c(800, 800, 799.45, 798.66327, 796.55208, 797.06061, 793.47826), tolerance = 1e-07)
-	expect_equal(resultsWithSSR1$numberOfSubjects[3, ], c(800, 800, 800, 800, 800, 800, 800), tolerance = 1e-07)
+	expect_equal(resultsWithSSR1$numberOfSubjects[3, ], c(800, 800, 800, 800, 800, 800, 800))
 	expect_equal(resultsWithSSR1$expectedNumberOfSubjects, c(800, 800, 799.934, 793.55401, 785.93916, 794.85349, 767.86699), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$rejectPerStage[1, ], c(0, 0, 0, 0.02, 0.04, 0.01, 0.08), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$rejectPerStage[2, ], c(0.04, 0.04, 0.12, 0.31, 0.46, 0.64, 0.81), tolerance = 1e-07)
@@ -1378,7 +1371,7 @@ test_that("'getSimulationSurvival': Perform recalculation of number of events ba
 	expect_equal(resultsWithSSR1$futilityPerStage[2, ], c(0, 0, 0, 0, 0, 0, 0))
 	expect_equal(resultsWithSSR1$futilityStop, c(0, 0, 0, 0, 0, 0, 0))
 	expect_equal(resultsWithSSR1$earlyStop, c(0.04, 0.04, 0.12, 0.33, 0.5, 0.65, 0.89), tolerance = 1e-07)
-	expect_equal(resultsWithSSR1$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(resultsWithSSR1$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(resultsWithSSR1$conditionalPowerAchieved[2, ], c(0.12165751, 0.15502837, 0.23497758, 0.29890789, 0.33886493, 0.41286728, 0.49916888), tolerance = 1e-07)
 	expect_equal(resultsWithSSR1$conditionalPowerAchieved[3, ], c(0.14749827, 0.23857933, 0.44868993, 0.59763371, 0.65378645, 0.66059558, 0.69812096), tolerance = 1e-07)
 
@@ -1407,7 +1400,7 @@ test_that("'getSimulationSurvival': Perform recalculation of number of events ba
 	expect_equal(resultsWithSSR2$analysisTime[2, ], c(17.532866, 16.792737, 15.753436, 15.242772, 14.414526, 13.395253, 12.536642), tolerance = 1e-07)
 	expect_equal(resultsWithSSR2$analysisTime[3, ], c(29.782185, 28.27297, 25.249508, 24.235039, 21.407797, 20.846814, 17.625231), tolerance = 1e-07)
 	expect_equal(resultsWithSSR2$studyDuration, c(29.663096, 27.530562, 24.305604, 21.136576, 18.176787, 16.398878, 13.170673), tolerance = 1e-07)
-	expect_equal(resultsWithSSR2$eventsPerStage[1, ], c(58, 58, 58, 58, 58, 58, 58), tolerance = 1e-07)
+	expect_equal(resultsWithSSR2$eventsPerStage[1, ], c(58, 58, 58, 58, 58, 58, 58))
 	expect_equal(resultsWithSSR2$eventsPerStage[2, ], c(229.71, 222.76, 213.91, 210.63265, 201.21875, 185.82828, 171.84783), tolerance = 1e-07)
 	expect_equal(resultsWithSSR2$eventsPerStage[3, ], c(403.55556, 395.78947, 365.25, 358.80282, 327.35, 327.17778, 272.14286), tolerance = 1e-07)
 	expect_equal(resultsWithSSR2$expectedNumberOfEvents, c(401.8171, 387.138, 353.1428, 312.78082, 271.16875, 248.15727, 183.80196), tolerance = 1e-07)
@@ -1426,7 +1419,7 @@ test_that("'getSimulationSurvival': Perform recalculation of number of events ba
 	expect_equal(resultsWithSSR2$futilityPerStage[2, ], c(0, 0, 0, 0, 0, 0, 0))
 	expect_equal(resultsWithSSR2$futilityStop, c(0, 0, 0, 0, 0, 0, 0))
 	expect_equal(resultsWithSSR2$earlyStop, c(0.01, 0.05, 0.08, 0.29, 0.4, 0.55, 0.79), tolerance = 1e-07)
-	expect_equal(resultsWithSSR2$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_), tolerance = 1e-07)
+	expect_equal(resultsWithSSR2$conditionalPowerAchieved[1, ], c(NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_))
 	expect_equal(resultsWithSSR2$conditionalPowerAchieved[2, ], c(0.13442705, 0.17515425, 0.27216274, 0.37121019, 0.42163288, 0.51345413, 0.62679958), tolerance = 1e-07)
 	expect_equal(resultsWithSSR2$conditionalPowerAchieved[3, ], c(0.088787205, 0.13342075, 0.37806621, 0.51790868, 0.64116584, 0.64220287, 0.73456911), tolerance = 1e-07)
 
